@@ -738,7 +738,7 @@ def bronze_to_silver(
                             tbl_properties.get('cortex.rowsCount'),
                             tbl_properties.get('cortex.lastUpdate'),
                             tbl_properties.get('cortex.createDate'),
-                            get_link_table(catalog_name, 'silver', output_db_table),
+                            get_link_table(catalog_name, 'silver', tbl_properties.get('cortex.tableName')),
                             'silver'
                         )
                     ]
@@ -748,7 +748,7 @@ def bronze_to_silver(
                     .mode('append')\
                     .saveAsTable("cortex.data_governance_quality.tables")
                 
-                set_comment_table(catalog_name, f'silver.{output_db_table}'  , tbl_properties.get('cortex.description'))
+                set_comment_table(catalog_name, output_db_table, tbl_properties.get('cortex.description'))
 
             except Exception as e:
                 print(e)
@@ -891,7 +891,7 @@ def silver_to_gold(
                             tbl_properties.get('cortex.lastUpdate'),
                             tbl_properties.get('cortex.createDate'),
                             tbl_properties.get('cortex.exposures'),
-                            get_link_table(catalog_name, 'gold', output_db_table),
+                            get_link_table(catalog_name, 'gold', tbl_properties.get('cortex.tableName')),
                             'gold'
                         )
                     ]
@@ -900,7 +900,7 @@ def silver_to_gold(
                     .format('delta')\
                     .mode('append')\
                     .saveAsTable("cortex.data_governance_quality.tables")
-                set_comment_table(catalog_name, f'gold.{output_db_table}'  , tbl_properties.get('cortex.description'))
+                set_comment_table(catalog_name, output_db_table, tbl_properties.get('cortex.description'))
 
             except Exception as e:
                 print(e)
